{% extends "base.html" %}
{% load static %}

{% block heading %}<h4>
    <img src="{% static "svg/help.svg" %}" width="30" height="30" alt="Help">
    Help</h4>{%endblock%}

{% block content %}
Help documentation here
{% endblock %}