# Generated by Django 2.2.12 on 2020-05-21 20:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0058_auto_20200517_2016'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='exif_lenstype',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='formula',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='exif_lenstype',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='formula',
        ),
    ]
