# Generated by Django 2.2.16 on 2020-11-06 21:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0098_auto_20201028_2117'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='history_user',
        ),
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='manufacturer',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='flash_metering',
        ),
        migrations.RemoveField(
            model_name='flash',
            name='flash_protocol',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='flash_metering',
        ),
        migrations.DeleteModel(
            name='FlashProtocol',
        ),
        migrations.DeleteModel(
            name='HistoricalFlashProtocol',
        ),
    ]
