# Generated by Django 2.2.13 on 2020-07-08 21:09

from django.db import migrations
import versatileimagefield.fields


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0067_auto_20200707_2125'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, help_text='Image of the camera model', null=True, upload_to=''),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='diagram',
            field=versatileimagefield.fields.VersatileImageField(blank=True, help_text='Block diagram of the optics', null=True, upload_to=''),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='image',
            field=versatileimagefield.fields.VersatileImageField(blank=True, help_text='Image of the lens model', null=True, upload_to=''),
        ),
    ]
