# Generated by Django 2.2 on 2020-03-23 20:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0042_cameramodel_mirror_lockup'),
    ]

    operations = [
        migrations.AlterField(
            model_name='lensmodel',
            name='coating',
            field=models.CharField(blank=True, choices=[('Uncoated', 'Uncoated'), ('Single coated', 'Single coated'), (
                'Multi coated', 'Multi coated')], help_text='Type of lens coating', max_length=15, null=True),
        ),
    ]
