# Generated by Django 2.2.13 on 2020-06-10 21:31

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0063_closest_focus'),
    ]

    operations = [
        migrations.AlterField(
            model_name='camera',
            name='condition',
            field=models.ForeignKey(blank=True, help_text='Condition of this camera. Refer to <a href="/help/condition">condition grading</a>', null=True, on_delete=django.db.models.deletion.CASCADE, to='schema.Condition'),
        ),
        migrations.AlterField(
            model_name='lens',
            name='condition',
            field=models.ForeignKey(blank=True, help_text='Condition of this lens. Refer to <a href="/help/condition">condition grading</a>', null=True, on_delete=django.db.models.deletion.CASCADE, to='schema.Condition'),
        ),
    ]
