# Generated by Django 2.2.9 on 2020-03-17 14:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0032_battery_compatible_with'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='battery',
            name='other_names',
        ),
        migrations.AlterField(
            model_name='battery',
            name='compatible_with',
            field=models.ManyToManyField(
                blank=True, help_text='Batteries that are compatible with this one', to='schema.Battery'),
        ),
    ]
