# Generated by Django 2.2.14 on 2020-08-25 19:54

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import simple_history.models


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('schema', '0075_auto_20200825_1920'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='battery',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='battery',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='battery',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='battery',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='cameramodel',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='developer',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='developer',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='developer',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='developer',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='filmstock',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='filmstock',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='filmstock',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='filmstock',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='flashprotocol',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='flashprotocol',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='flashprotocol',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='flashprotocol',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='format',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='format',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='format',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='format',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalbattery',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalbattery',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalbattery',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalbattery',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicaldeveloper',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicaldeveloper',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicaldeveloper',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicaldeveloper',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalfilmstock',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalfilmstock',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalfilmstock',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalfilmstock',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalflashprotocol',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalformat',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalformat',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalformat',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalformat',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalmanufacturer',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalmanufacturer',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalmanufacturer',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalmanufacturer',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalmount',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalmount',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalmount',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalmount',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalnegativesize',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalnegativesize',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalnegativesize',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalnegativesize',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicalpaperstock',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicalpaperstock',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicalpaperstock',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicalpaperstock',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='historicaltoner',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='historicaltoner',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='historicaltoner',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='historicaltoner',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='manufacturer',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='manufacturer',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='manufacturer',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='manufacturer',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='mount',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='mount',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='mount',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='mount',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='negativesize',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='negativesize',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='negativesize',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='negativesize',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='paperstock',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='paperstock',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='paperstock',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='paperstock',
            name='updated_by',
        ),
        migrations.RemoveField(
            model_name='toner',
            name='created_at',
        ),
        migrations.RemoveField(
            model_name='toner',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='toner',
            name='updated_at',
        ),
        migrations.RemoveField(
            model_name='toner',
            name='updated_by',
        ),
        migrations.CreateModel(
            name='HistoricalProcess',
            fields=[
                ('id', models.IntegerField(auto_created=True, blank=True, db_index=True, verbose_name='ID')),
                ('name', models.CharField(db_index=True, help_text='Name of this developmenmt process (e.g. C-41, E-6)', max_length=25)),
                ('colour', models.BooleanField(blank=True, help_text='Whether this is a colour process', null=True)),
                ('positive', models.BooleanField(blank=True, help_text='Whether this is a positive/reversal process', null=True)),
                ('history_id', models.AutoField(primary_key=True, serialize=False)),
                ('history_date', models.DateTimeField()),
                ('history_change_reason', models.CharField(max_length=100, null=True)),
                ('history_type', models.CharField(choices=[('+', 'Created'), ('~', 'Changed'), ('-', 'Deleted')], max_length=1)),
                ('history_user', models.ForeignKey(null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.AUTH_USER_MODEL)),
            ],
            options={
                'verbose_name': 'historical process',
                'ordering': ('-history_date', '-history_id'),
                'get_latest_by': 'history_date',
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
    ]
