# Generated by Django 2.2 on 2020-03-21 23:30

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0039_auto_20200321_2236'),
    ]

    operations = [
        migrations.AlterField(
            model_name='developer',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this developer',
                                    on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
        migrations.AlterField(
            model_name='filmstock',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this film',
                                    on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this lens model',
                                    on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
        migrations.AlterField(
            model_name='toner',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this toner',
                                    on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
        migrations.AlterUniqueTogether(
            name='lensmodel',
            unique_together=set(),
        ),
        migrations.AddConstraint(
            model_name='developer',
            constraint=models.UniqueConstraint(
                fields=('manufacturer', 'name'), name='developer_unique_name'),
        ),
        migrations.AddConstraint(
            model_name='filmstock',
            constraint=models.UniqueConstraint(
                fields=('manufacturer', 'name'), name='filmstock_unique_name'),
        ),
        migrations.AddConstraint(
            model_name='lensmodel',
            constraint=models.UniqueConstraint(fields=(
                'manufacturer', 'model', 'disambiguation'), name='lensmodel_unique_name'),
        ),
        migrations.AddConstraint(
            model_name='toner',
            constraint=models.UniqueConstraint(
                fields=('manufacturer', 'name'), name='toner_unique_name'),
        ),
    ]
