# Generated by Django 2.2.4 on 2019-10-16 10:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0009_auto_20191015_0926'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='video',
        ),
        migrations.RemoveField(
            model_name='projector',
            name='cine',
        ),
        migrations.DeleteModel(
            name='Movie',
        ),
    ]
