# Generated by Django 2.2.9 on 2020-03-31 14:48

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0050_auto_20200327_2303'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='series',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='series',
        ),
        migrations.DeleteModel(
            name='Series',
        ),
    ]
