# Generated by Django 2.2.14 on 2020-08-10 18:12

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0068_auto_20200708_2109'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='self_timer',
            field=models.BooleanField(blank=True, help_text='Whether the camera has a self-timer', null=True),
        ),
        migrations.AddField(
            model_name='historicalcameramodel',
            name='self_timer',
            field=models.BooleanField(blank=True, help_text='Whether the camera has a self-timer', null=True),
        ),
    ]
