# Generated by Django 2.2 on 2020-04-17 19:54

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0051_auto_20200331_1448'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='url',
            field=models.URLField(blank=True, help_text='URL to more information about this camera model', null=True, verbose_name='URL'),
        ),
    ]
