# Generated by Django 2.2.14 on 2020-08-20 20:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0073_auto_20200818_2118'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='rectilinear',
        ),
        migrations.RemoveField(
            model_name='historicalcameramodel',
            name='rectilinear',
        ),
        migrations.RemoveField(
            model_name='historicallensmodel',
            name='rectilinear',
        ),
        migrations.RemoveField(
            model_name='lensmodel',
            name='rectilinear',
        ),
    ]
