{% load static %}
{% load version %}

<p align="center">
        <a href="https://www.facebook.com/camerahubapp" target="_blank"><img src="{% static "svg/facebook.svg" %}"
                        width="30" height="30" alt="Facebook" title="Facebook"></a>
        <a href="https://github.com/djjudas21/camerahub" target="_blank"><img src="{% static "svg/github.svg" %}"
                        width="30" height="30" alt="Github" title="Github"></a>
        <a href="mailto:support@camerahub.info"><img src="{% static "svg/mail.svg" %}" width="30" height="30"
                        alt="Mail"></a>
        <a href="https://icons8.com/icons" target="_blank"><img src="{% static "svg/icons8.svg" %}" width="30"
                        height="30" alt="Icons8" title="Icons8"></a>
        <br>
        <small>CameraHub v{% camerahub_version %}</small>
</p>
