# Generated by Django 2.2 on 2020-03-20 22:23

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0034_auto_20200317_2149'),
    ]

    operations = [
        migrations.AddField(
            model_name='cameramodel',
            name='slug',
            field=models.SlugField(editable=False, null=True, unique=True),
        ),
    ]
