# Generated by Django 2.2.17 on 2020-11-24 19:55

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0106_auto_20201118_2155'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='enlargermodel',
            options={'ordering': ['manufacturer', 'model'], 'verbose_name_plural': 'enlarger models'},
        ),
        migrations.AddField(
            model_name='enlargermodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for enlarger models with the same name', max_length=45),
        ),
        migrations.AddField(
            model_name='historicalenlargermodel',
            name='disambiguation',
            field=models.CharField(blank=True, default='', help_text='Distinguishing notes for enlarger models with the same name', max_length=45),
        ),
        migrations.AlterField(
            model_name='print',
            name='enlarger',
            field=models.ForeignKey(blank=True, help_text='Enlarger used to make this print', null=True, on_delete=django.db.models.deletion.CASCADE, to='schema.Enlarger'),
        ),
        migrations.AddConstraint(
            model_name='enlargermodel',
            constraint=models.UniqueConstraint(fields=('manufacturer', 'model', 'disambiguation'), name='enlargermodel_unique_name'),
        ),
    ]
