# Generated by Django 2.2.4 on 2019-11-07 11:08

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0014_auto_20191031_1127'),
    ]

    operations = [
        migrations.AlterField(
            model_name='print',
            name='toner',
            field=models.ManyToManyField(
                blank=True, help_text='Toners and bleaches used to treat this print', through='schema.Toning', to='schema.Toner'),
        ),
    ]
