# Generated by Django 2.2 on 2020-03-21 21:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0036_cameramodel_slug'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='manufacturer',
            field=models.ForeignKey(help_text='Manufacturer of this camera model',
                                    on_delete=django.db.models.deletion.CASCADE, to='schema.Manufacturer'),
        ),
    ]
