# Generated by Django 2.2 on 2020-02-29 19:54

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0021_auto_20200222_1856'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='cameramodel',
            unique_together={('manufacturer', 'model', 'disambiguation')},
        ),
        migrations.AlterUniqueTogether(
            name='lensmodel',
            unique_together={('manufacturer', 'model', 'disambiguation')},
        ),
    ]
