# Generated by Django 2.2.16 on 2020-10-13 09:29

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0090_film_status'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='film',
            options={'ordering': ['id_owner'], 'verbose_name_plural': 'films'},
        ),
    ]
