# Generated by Django 2.2.16 on 2020-11-12 20:32

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0100_remove_film_directory'),
    ]

    operations = [
        migrations.AddField(
            model_name='negative',
            name='slug',
            field=models.SlugField(editable=False, null=True),
        ),
    ]
