{% extends "base.html" %}
{% load static %}

{% block heading %}<h4>
    <img src="{% static "svg/stats.svg" %}" width="30" height="30" alt="{{ title }}">
    {{ title }}</h4>{%endblock%}

{% block content %}
<div class="container">
    <div class="row justify-content-center">
        <ul class="list-unstyled">
            {% for stat in stats %}
            <li class="media my-4">
                <a href="{{ stat.url }}"><img class="mr-3" src="{% static stat.image %}" style="width: 80px"></a>
                <div class="media-body">
                    <h4 class="mt-0 mb-1">{{ stat.value }}</h4>
                    {% if stat.subheading %}<h5 class="mt-0 mb-1">{{ stat.subheading }}</h5>{% endif %}
                    <p>{{ stat.item }}</p>
                </div>
            </li>
            {% endfor %}
        </ul>
    </div>
</div>
{% endblock %}
