# Generated by Django 2.2.12 on 2020-05-29 20:59

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0061_zoom_ratio'),
    ]

    operations = [
        migrations.AlterField(
            model_name='cameramodel',
            name='closest_focus',
            field=models.DecimalField(blank=True, decimal_places=2, help_text='The closest focus possible with this lens, in m', max_digits=6, null=True),
        ),
        migrations.AlterField(
            model_name='lensmodel',
            name='closest_focus',
            field=models.DecimalField(blank=True, decimal_places=2, help_text='The closest focus possible with this lens, in m', max_digits=6, null=True),
        ),
    ]
