# Generated by Django 2.2 on 2020-03-23 20:47

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0043_auto_20200323_2001'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='cameramodel',
            name='coupled_metering',
        ),
    ]
