# Generated by Django 2.2.9 on 2020-03-17 14:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('schema', '0030_auto_20200317_1344'),
    ]

    operations = [
        migrations.AlterField(
            model_name='battery',
            name='chemistry',
            field=models.CharField(blank=True, choices=[('Alkaline', 'Alkaline'), ('Nickel cadmium', 'Nickel cadmium'), ('Nickel metal hydride', 'Nickel metal hydride'), ('Carbon zinc', 'Carbon zinc'), ('Lithium', 'Lithium'), (
                'Lithium ion', 'Lithium ion'), ('Lithium polymer', 'Lithium polymer'), ('Mercury', 'Mercury'), ('Zinc air', 'Zinc air'), ('Silver oxide', 'Silver oxide')], help_text='Battery chemistry', max_length=45, null=True),
        ),
    ]
